@@ -11,8 +11,8 @@
 ################################################################################
 
 INSTALLER_NAME="Rootkit Hunter installer"
-INSTALLER_VERSION="1.2.7"
-INSTALLER_COPYRIGHT="Copyright 2003-2007, Michael Boelen"
+INSTALLER_VERSION="1.2.8"
+INSTALLER_COPYRIGHT="Copyright 2003-2008, Michael Boelen"
 INSTALLER_LICENSE="
 
 Under active development by the Rootkit Hunter project team. For reporting
@@ -24,12 +24,14 @@ of the GNU General Public License. See LICENSE for details.
 "
 
 APPNAME="rkhunter"
-APPVERSION="1.3.2"
+APPVERSION="1.3.4"
 RKHINST_OWNER="0:0"
 RKHINST_MODE_EX="0750"
 RKHINST_MODE_RW="0640"
 RKHINST_MODE_RWR="0644"
 RKHINST_LAYOUT=""
+RKHINST_ACTION=""
+RKHINST_ACTION_SEEN=0
 USE_CVS=0
 STRIPROOT=""
 N="-n"
@@ -101,6 +103,7 @@ showHelp() { # Show help / version
 	echo $ECHOOPT "                    - oldschool: previous version file locations,"
 	echo $ECHOOPT "                    - custom: supply your own prefix,"
 	echo $ECHOOPT "                    - RPM: for building RPM's. Requires \$RPM_BUILD_ROOT."
+	echo $ECHOOPT "                    - DEB: for building DEB's. Requires \$DEB_BUILD_ROOT."
 	echo $ECHOOPT "--striproot      : Strip path from custom layout (for package maintainers)."
 	echo $ECHOOPT "--install        : Install according to chosen layout."
 	echo $ECHOOPT "--show           : Show chosen layout."
@@ -138,7 +141,7 @@ showVersion() { echo "${INSTALLER_NAME} ${INSTALLER_VERSION} ${INSTALLER_LICENSE
 
 selectTemplate() { # Take input from the "--installdir parameter"
 case "$1" in
-	/usr|/usr/local|default|custom_*|RPM)
+	/usr|/usr/local|default|custom_*|RPM|DEB)
 		case "$1" in
 			default)
 				PREFIX="/usr/local"
@@ -147,7 +150,7 @@ case "$1" in
 				PREFIX=`echo "${RKHINST_LAYOUT}"|sed "s|custom_||g"`
 				case "${PREFIX}" in
 					.)
-						if [ "$action" = "install" ]; then
+						if [ "${RKHINST_ACTION}" = "install" ]; then
 							echo "Standalone installation into ${PWD}/files"
 						fi
 						;;
@@ -156,7 +159,7 @@ case "$1" in
 						exit 1
 						;;
 					*)
-						if [ "$action" = "install" ]; then
+						if [ "${RKHINST_ACTION}" = "install" ]; then
 							RKHTMPVAR=`echo "${PATH}" | grep "${PREFIX}/bin"`
 							if [ -z "${RKHTMPVAR}" ]; then
 								echo ""
@@ -174,14 +177,21 @@ case "$1" in
 					exit 1
 				fi
 				;;
+			DEB)    if [ -n "${DEB_BUILD_ROOT}" ]; then
+					PREFIX="${DEB_BUILD_ROOT}/usr"
+				else
+					echo "DEB prefix chosen but \$DEB_BUILD_ROOT variable not found, exiting."
+					exit 1
+				fi
+				;;
 			*)	PREFIX="$1"
 				;;
 		esac
 		case "$1" in
-			RPM)
+			RPM|DEB)
 				;;
 			*)
-				if [ "$action" = "install" ]; then
+				if [ "${RKHINST_ACTION}" = "install" ]; then
 					if [ ! -d "${PREFIX}" ]; then
 						echo "Bad prefix chosen (non-existent directory), exiting."
 						echo "Perhaps run \"mkdir -p ${PREFIX}\" first?"
@@ -196,6 +206,8 @@ case "$1" in
 				;;
 			RPM)	SYSCONFIGDIR="${RPM_BUILD_ROOT}/etc"
 				;;
+			DEB)    SYSCONFIGDIR="${DEB_BUILD_ROOT}/etc"
+				;;
 			*)	SYSCONFIGDIR="/etc"
 				;;
 		esac
@@ -217,6 +229,11 @@ case "$1" in
 				VARDIR="${RPM_BUILD_ROOT}/var"
 				SHAREDIR="${PREFIX}/share"; BINDIR="${PREFIX}/bin"
 				;;
+			DEB)
+				LIBDIR="${PREFIX}/lib"
+				VARDIR="${DEB_BUILD_ROOT}/var"
+				SHAREDIR="${PREFIX}/share"; BINDIR="${PREFIX}/bin"
+				;;
 			*)
 				if [ -d "${PREFIX}/lib64" ]; then
 					LIBDIR="${PREFIX}/lib64"
@@ -246,6 +263,11 @@ if [ "${RKHINST_LAYOUT}" = "oldschool" ]; then
 	RKHINST_DB_DIR="${VARDIR}/${APPNAME}/db"
 	RKHINST_TMP_DIR="${VARDIR}/${APPNAME}/tmp"
 	RKHINST_DOC_DIR="${SHAREDIR}/${APPNAME}/docs"
+elif [ "${RKHINST_LAYOUT}" = "DEB" ]; then
+	RKHINST_DB_DIR="${VARDIR}/lib/${APPNAME}/db"
+	RKHINST_TMP_DIR="${VARDIR}/lib/${APPNAME}/tmp"
+	RKHINST_DOC_DIR="${SHAREDIR}/doc/${APPNAME}"
+	RKHINST_SCRIPT_DIR="${SHAREDIR}/${APPNAME}/scripts"
 else
 	RKHINST_DB_DIR="${VARDIR}/lib/${APPNAME}/db"
 	RKHINST_TMP_DIR="${VARDIR}/lib/${APPNAME}/tmp"
@@ -259,7 +281,11 @@ RKHINST_ETC_FILE="${APPNAME}.conf"
 RKHINST_BIN_FILES="${APPNAME}"
 RKHINST_SCRIPT_FILES="check_modules.pl check_update.sh check_port.pl filehashmd5.pl filehashsha1.pl showfiles.pl stat.pl readlink.sh"
 RKHINST_DB_FILES="backdoorports.dat mirrors.dat os.dat programs_bad.dat programs_good.dat defaulthashes.dat md5blacklist.dat suspscan.dat"
-RKHINST_DOC_FILES="ACKNOWLEDGMENTS CHANGELOG FAQ LICENSE README WISHLIST"
+if [ "${RKHINST_LAYOUT}" = "DEB" ]; then
+	RKHINST_DOC_FILES="ACKNOWLEDGMENTS FAQ README WISHLIST"
+else
+	RKHINST_DOC_FILES="ACKNOWLEDGMENTS CHANGELOG FAQ LICENSE README WISHLIST"
+fi
 RKHINST_MAN_FILES="${APPNAME}.8"
 
 }
@@ -267,7 +293,7 @@ RKHINST_MAN_FILES="${APPNAME}.8"
 # Additions we need to be aware / take care of:
 # any /contrib/ files which should include any RH*L/alike ones:
 # Additions we need to be aware / take care of wrt RH*L/alike:
-# /etc/cron.daily/01-rkhunter (different versions of cronjob)
+# /etc/cron.daily/rkhunter (different versions of cronjob)
 # /etc/sysconfig/rkhunter (config for cronjob)
 # /etc/logrotate.d/rkhunter
 
@@ -330,7 +356,7 @@ else
 			rm -rf "${dir}"; retValChk
 		done
 		case "${RKHINST_LAYOUT}" in
-		RPM) 
+		RPM|DEB) 
 			;;
 		*)
 			find ./files | while read ITEM; do
@@ -367,7 +393,7 @@ if [ -f "./files/${APPNAME}" ]; then
 		useCVS
 	fi
 	case "${RKHINST_LAYOUT}" in
-	RPM) 
+	RPM|DEB) 
 		;;
 	*)
 		find ./files | while read ITEM; do
@@ -408,7 +434,7 @@ echo "Starting installation/update"
 echo ""
 
 case "${RKHINST_LAYOUT}" in
-		RPM)
+		RPM|DEB)
 			;;
 		*) 
 # Check PREFIX
@@ -544,7 +570,7 @@ done; retValChk
 for FILE in ${RKHINST_BIN_FILES}; do
 	echo $N " Installing ${FILE}: " 
 	case "${RKHINST_LAYOUT}" in
-		RPM)	
+		RPM|DEB)	
 			cp -f ./files/"${FILE}" "${RKHINST_BIN_DIR}/${FILE}"; retValChk
 			;;
 		*)	
@@ -576,7 +602,7 @@ for FILE in ${RKHINST_ETC_FILE}; do
 		echo "SCRIPTDIR=${RKHINST_SCRIPT_DIR}" >> "${RKHINST_ETC_DIR}/${NEWFILE}"
 		echo "TMPDIR=${RKHINST_TMP_DIR}" >> "${RKHINST_ETC_DIR}/${NEWFILE}"
 
-		if [ "${RKHINST_LAYOUT}" != "RPM" ]; then
+		if [ "${RKHINST_LAYOUT}" != "RPM" -a "${RKHINST_LAYOUT}" != "DEB" ]; then
 			echo " >>> "
 			echo " >>> PLEASE NOTE: inspect for update changes in "${RKHINST_ETC_DIR}/${NEWFILE}""
 			echo " >>> and apply to "${RKHINST_ETC_DIR}/${FILE}" before running Rootkit Hunter."
@@ -593,7 +619,8 @@ for FILE in ${RKHINST_ETC_FILE}; do
 			echo "DBDIR=${RKHINST_DB_DIR}" | sed "s|${RPM_BUILD_ROOT}||g" >> "${RKHINST_ETC_DIR}/${FILE}"
 			echo "SCRIPTDIR=${RKHINST_SCRIPT_DIR}" | sed "s|${RPM_BUILD_ROOT}||g" >> "${RKHINST_ETC_DIR}/${FILE}"
 			echo "TMPDIR=${RKHINST_TMP_DIR}" | sed "s|${RPM_BUILD_ROOT}||g" >> "${RKHINST_ETC_DIR}/${FILE}"
-		else
+		# Done with a patch during the build process
+		elif [ -z "${DEB_BUILD_ROOT}" ]; then
 			echo "INSTALLDIR=${PREFIX}" >> "${RKHINST_ETC_DIR}/${FILE}"
 			echo "DBDIR=${RKHINST_DB_DIR}" >> "${RKHINST_ETC_DIR}/${FILE}"
 			echo "SCRIPTDIR=${RKHINST_SCRIPT_DIR}" >> "${RKHINST_ETC_DIR}/${FILE}"
@@ -613,7 +640,7 @@ fi
 # to avoid warnings when rkhunter is first run.
 
 case "${RKHINST_LAYOUT}" in
-	RPM)	# This is done by a %post section in the spec file.
+	RPM|DEB)	# This is done by a %post section in the spec file / postinst file.
 		;;
 	*)
 		cp -p /etc/passwd ${RKHINST_TMP_DIR} >/dev/null 2>&1
@@ -752,11 +779,11 @@ while [ $# -ge 1 ]; do
 					exit 1
 				fi
 				;;
-			default|oldschool|/usr|/usr/local|RPM)
+			default|oldschool|/usr|/usr/local|RPM|DEB)
 				RKHINST_LAYOUT="$1"
 				;;
 			*)
-				echo "Unknown layout given, exiting."
+				echo "Unknown layout given, exiting: $1"
 				exit 1
 				;;
 		esac
@@ -775,8 +802,11 @@ while [ $# -ge 1 ]; do
 			echo "No layout given. The '--layout' option must be specified first."
 			exit 1
 		fi
-		action=`echo $ECHOOPT "$1"|sed "s/-//g"`
-		case "$action" in
+
+		RKHINST_ACTION_SEEN=1
+		RKHINST_ACTION=`echo $ECHOOPT "$1"|sed "s/-//g"`
+
+		case "${RKHINST_ACTION}" in
 			show)	showTemplate $RKHINST_LAYOUT
 				;;
 			remove)	# Clean active window
@@ -792,7 +822,7 @@ while [ $# -ge 1 ]; do
 			"")	echo "No action given, exiting."
 				exit 1
 				;;
-			*)	echo "Unknown action given, exiting: $action"
+			*)	echo "Unknown action given, exiting: ${RKHINST_ACTION}"
 				exit 1
 				;;
 		esac
@@ -807,4 +837,9 @@ while [ $# -ge 1 ]; do
 	shift
 done
 
+# We only get here when some installation action was to be taken.
+if [ $RKHINST_ACTION_SEEN -eq 0 ]; then
+	echo "No action given, exiting."
+fi
+
 exit 0
